@@ -177,6 +177,9 @@ def _get_model(args, func):
     if hasattr(func, "__self__"):
         # Bound method
         model = func.__self__.model
+    elif hasattr(func, "__wrapped__"):
+        # Proxy model
+        model = func.__wrapped__.__self__.model
     else:
         # Custom method on user-defined model manager.
         model = args[0].model
